@@ -4,8 +4,8 @@ from __future__ import annotations
 import base64
 
 import attr
-from terra_proto.ibc.core.commitment.v1 import MerkleRoot as MerkleRoot_pb
 from terra_proto.ibc.core.commitment.v1 import MerklePrefix as MerklePrefix_pb
+from terra_proto.ibc.core.commitment.v1 import MerkleRoot as MerkleRoot_pb
 
 from terra_sdk.util.json import JSONSerializable
 
@@ -21,21 +21,14 @@ class MerkleRoot(JSONSerializable):
 
     @classmethod
     def from_data(cls, data: dict) -> MerkleRoot:
-        return cls(
-            hash=base64.b64decode(data["hash"])
-        )
+        return cls(hash=base64.b64decode(data["hash"]))
 
     def to_proto(self) -> MerkleRoot_pb:
-        return MerkleRoot_pb(
-            hash=base64.b64encode(self.hash)
-        )
+        return MerkleRoot_pb(hash=base64.b64encode(self.hash))
 
     @classmethod
     def from_proto(cls, proto: MerkleRoot_pb) -> MerkleRoot:
-        return cls(
-            hash=base64.b64decode(proto.hash)
-        )
-
+        return cls(hash=base64.b64decode(proto.hash))
 
 
 @attr.s
@@ -47,17 +40,11 @@ class MerklePrefix(JSONSerializable):
 
     @classmethod
     def from_data(cls, data: dict) -> MerklePrefix:
-        return cls(
-            key_prefix=base64.b64decode(data["key_prefix"])
-        )
+        return cls(key_prefix=base64.b64decode(data["key_prefix"]))
 
     def to_proto(self) -> MerklePrefix_pb:
-        return MerklePrefix_pb(
-            key_prefix=base64.b64encode(self.key_prefix)
-        )
+        return MerklePrefix_pb(key_prefix=base64.b64encode(self.key_prefix))
 
     @classmethod
     def from_proto(cls, proto: MerklePrefix_pb) -> MerklePrefix:
-        return cls(
-            key_prefix=base64.b64decode(proto.key_prefix)
-        )
+        return cls(key_prefix=base64.b64decode(proto.key_prefix))
